@@ -1,6 +1,6 @@
 # Statistics Menu dialogs
 
-# last modified 2023-08-07 by J. Fox
+# last modified 2023-09-25 by J. Fox
 
 # Means menu
 
@@ -42,6 +42,7 @@ independentSamplesTTest <- function () {
         #                    alternative, "', conf.level=", level, ", var.equal=", 
         #                    variances, ", data=", ActiveDataSet(), ")", sep = ""))
         command <- Command("t.test", paste(response, "~", group), alternative=Q(alternative),
+                           conf.level=level,
                            var.equal=variances, data=ActiveDataSet())
         doItAndPrint(command)
         tkfocus(CommanderWindow())
@@ -293,7 +294,6 @@ oneWayAnova <- function () {
                              sep = "")
         commands[2] <- "  print(summary(.Pairs)) # pairwise tests"
         commands[3] <- paste0("  print(confint(.Pairs, level=", level, ")) # confidence intervals")
-        commands[3] <- Command("") 
         commands[4] <- paste0("  print(cld(.Pairs, level=", alpha, ")) # compact letter display")
         commands[5] <- "  old.oma <- par(oma=c(0, 5, 0, 0))"
         commands[6] <- "  plot(confint(.Pairs))"
